@@ -6,7 +6,7 @@ use strict;
 use 5.008;
 
 
-our $VERSION = '0.1.9';
+our $VERSION = '0.1.10';
 
 
 package HTML::Latemp::News::Base;
@@ -303,7 +303,7 @@ web frameworks)
 
 =head1 VERSION
 
-version 0.1.9
+version 0.1.10
 
 =head1 SYNOPSIS
 
@@ -457,7 +457,7 @@ This generates an HTML news box with the recent headlines.
 
 =head1 AUTHOR
 
-Shlomi Fish, C<< <shlomif@iglu.org.il> >>
+Shlomi Fish, L<http://www.shlomifish.org/> .
 
 =head1 BUGS
 
@@ -541,7 +541,7 @@ RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=HTML-Latemp-News>
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=HTML-Latemp-News>
 
 =item *
 
@@ -573,7 +573,7 @@ CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
 
-L<http://cpants.perl.org/dist/overview/HTML-Latemp-News>
+L<http://cpants.cpanauthors.org/dist/HTML-Latemp-News>
 
 =item *
 
@@ -604,7 +604,7 @@ L<http://deps.cpantesters.org/?module=HTML::Latemp::News>
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests by email to C<bug-html-latemp-news at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=HTML-Latemp-News>. You will be automatically notified of any
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=HTML-Latemp-News>. You will be automatically notified of any
 progress on the request by the system.
 
 =head2 Source Code
